[FFmpeg-devel] [PATCH] avformat/flvenc: fix pts_wrap_bits

Zhao Zhili quinkblack at foxmail.com
Wed Mar 9 16:05:57 EET 2022


put_timestamp() only use 31 bits.
---
 libavformat/flvenc.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/libavformat/flvenc.c b/libavformat/flvenc.c
index 66c530a2ff..ef3d3cd60f 100644
--- a/libavformat/flvenc.c
+++ b/libavformat/flvenc.c
@@ -673,7 +673,7 @@ static int flv_init(struct AVFormatContext *s)
                    av_get_media_type_string(par->codec_type), i);
             return AVERROR(EINVAL);
         }
-        avpriv_set_pts_info(s->streams[i], 32, 1, 1000); /* 32 bit pts in ms */
+        avpriv_set_pts_info(s->streams[i], 31, 1, 1000); /* 31 bit pts in ms */
 
         sc = av_mallocz(sizeof(FLVStreamContext));
         if (!sc)
-- 
2.31.1



More information about the ffmpeg-devel mailing list